#!/bin/sh
##############################################################################
#
#  Copyright (c) 2005, Doremi Labs, Inc.
#    All rights reserved.
#
#  Redistribution in source or binary forms, with or without
#  modification, are NOT permitted.
#
#    Doremi Labs, Inc.
#    1020 Chestnut St.
#    Burbank, CA 91506
#    Tel : (818) 562 1101
#    Fax : (818) 562 1109
#
##############################################################################

. /doremi/etc/init.d/functions

#
#  ingest_init()
#    Create all ingest directories.
#
ingest_init()
{
	#  
	# '/data/incoming/gui' is a default folder always scanned by
	#   the ingest GUI.
	#
	install -m 0775 -o ingest -g users -d /data/incoming
	install -m 0775 -o ingest -g users -d /data/incoming/gui 
	touch /data/incoming/gui/.no_scan

	#
	# KDMs are now in '/doremi/kdms' instead of '/data/kdms' which
	#  is only a symbolic link to '/doremi/kdms'
	#
	install -m 0775 -o root -g admin   -d /doremi/kdms
	if [ -e /data/kdms ] && [ ! -L /data/kdms ]; then
		ts=$(date +"%a %b %e %T %Y")
		echo "[$ts][WARNG]: /data/kdms is not a symbolic link, fixing" >> /doremi/log/ingest_mgr.log
	fi
	if [ ! -L "/data/kdms" ]; then
		rm -rf /data/kdms
		ln -sf /doremi/kdms /data/kdms
	fi

	#
	# DLMs are now in '/doremi/dlms' instead of '/data/dlms' which
	#  is only a symbolic link to '/doremi/dlms'
	#
	install -m 0775 -o root -g admin   -d /doremi/dlms
	if [ -e /data/dlms ] && [ ! -L /data/dlms ]; then
		ts=$(date +"%a %b %e %T %Y")
		echo "[$ts][WARNG]: /data/dlms is not a symbolic link, fixing" >> /doremi/log/ingest_mgr.log
	fi
	if [ ! -L "/data/dlms" ]; then
		rm -rf /data/dlms
		ln -sf /doremi/dlms /data/dlms
	fi

	install -m 0775 -o ingestkdm -g ingest -d /doremi/incoming

	#
	# Create repository folders
	#
	install -m 0755 -o root -g root -d /data/maps
	install -m 0755 -o root -g root -d /data/assets
	install -m 0755 -o root -g root -d /data/repository
	install -m 0755 -o root -g root -d /data/repository/primary
	install -m 0755 -o root -g root -d /data/repository/secondary

	#
	# Create /data/tmp and clean it up if the script is run by init.
	#
	if [ "$RUNLEVEL" == "2" ] ; then
		rm -rf /data/tmp
	fi
	install -m 01777 -o root -g root -d /data/tmp
	touch /data/tmp/.clean
	install -m 1775 -o root -g root -d /data/tmp/rpls

	#
	# Create /doremi/tmp and clean it up if the script is run by init.
	#
	if [ "$RUNLEVEL" == "2" ] ; then
		rm -rf /doremi/tmp
	fi
	install -m 01777 -o root -g root -d /doremi/tmp
	touch /doremi/tmp/.clean
	
	#
	# Create /doremi/ingest.
	#
	install -m 0775 -o root -g admin -d /doremi/ingest
	touch /doremi/ingest/.no_scan
	
	# initialize the asset2cpl db
	/doremi/bin/ingestc.out --init /data
}
