#!/bin/sh
##############################################################################
#
#  Copyright (c) 2008, Doremi Labs, Inc.
#    All rights reserved.
#
#  Redistribution in source or binary forms, with or without
#  modification, are NOT permitted.
#
#    Doremi Labs, Inc.
#    306 East Alameda Avenue
#    Burbank, CA 91502
#    Tel : (818) 562 1101
#    Fax : (818) 562 1109
#
#
##############################################################################

HOT_FIX="X11vnc-1.9 remover"
LOGFILE="/doremi/log/update.log"
DONE=0

remount_rootfs_rw()
{
  test -n "${rootfsisro}" && mount -o remount,rw /
}

remount_rootfs_ro()
{
  sync
  test -n "${rootfsisro}" && mount -o remount,ro /
}

vnc_remove_module()
{
  CFILE=$1

  if ! test -r $CFILE; then
    return 0
  fi
  # test load vnc instruction
  if grep -s Load ${CFILE} | grep -qs vnc; then
    remount_rootfs_rw
    sed -i '/^[ \t]*Load[ \t]*"vnc"$/d' ${CFILE}
    remount_rootfs_ro
    DONE=1
  fi
  return 0
}

vnc_remove_password()
{
  CFILE=$1

  if ! test -r $CFILE; then
    return 0
  fi
  # check option password file
  if grep -s Option ${CFILE} | grep -qs PasswordFile; then
    remount_rootfs_rw
    sed -i '/^[ \t]*Option[ \t]*"PasswordFile".*$/d' ${CFILE}
    remount_rootfs_ro
    DONE=1
  fi
  return 0
}

if mount | grep 'on / ' | grep -v rootfs | grep -q '(ro)'; then
  rootfsisro=true
fi

# remove handlers and password file
rm -f /doremi/etc/upgrade/post.d/X11vnc
rm -f /doremi/etc/vnc/passwd

# revert configuration file
if test -r /etc/X11/XF86Config-4; then
  CFILE=/etc/X11/XF86Config-4
elif test -r /etc/X11/xorg.conf; then
  CFILE=/etc/X11/xorg.conf
else
  echo '['`date`']:' "${HOT_FIX}: Error: configuration file not found" >> ${LOGFILE}
  exit -1
fi

# Xorg configuration file
vnc_remove_module   /etc/X11/xorg.conf
vnc_remove_password /etc/X11/xorg.conf

# Xfree86 configuratino file
vnc_remove_module   /etc/X11/XF86Config-4
vnc_remove_password /etc/X11/XF86Config-4

# cleanup
if [ -f /etc/X11/XF86Config-4.rej ] ; then
  remount_rootfs_rw
  rm -f /etc/X11/XF86Config-4.rej
  remount_rootfs_ro
  DONE=1
fi
if [ -f /etc/X11/xorg.conf.rej ]; then
  remount_rootfs_rw
  rm -f /etc/X11/xorg.conf.rej
  remount_rootfs_ro
  DONE=1
fi

if [ ${DONE} -gt 0 ]; then
  # update running display
  if test -e /tmp/.X11-unix/X0; then
    pkill -INT X
    pkill -INT Xorg
  fi
fi

echo '['`date`']:' ${HOT_FIX}: package removed. >> ${LOGFILE}

